@@ -25,7 +25,16 @@ nobs.sdmTMB <- function(object, ...) {
 #' @export
 #' @noRd
 fitted.sdmTMB <- function(object, ...) {
-  predict(object, type = "response")$est
+  if (isTRUE(object$family$delta)) {
+    inv1 <- object$family[[1]]$linkinv
+    p1 <- inv1(predict(object, type = "link")$est1)
+    inv2 <- object$family[[2]]$linkinv
+    p2 <- inv2(predict(object, type = "link")$est2)
+    p1 * p2
+  } else {
+    inv <- object$family$linkinv
+    inv(predict(object, type = "link")$est)
+  }
 }
 
 #' Extract the log likelihood of a sdmTMB model
@@ -77,7 +86,7 @@ family.sdmTMB <- function (object, ...) {
 #' @method fixef sdmTMB
 #' @export
 fixef.sdmTMB <- function(object, ...) {
-  .t <- tidy(object)
+  .t <- tidy(object, silent = TRUE)
   bhat <- .t$estimate
   names(bhat) <- .t$term
   bhat
@@ -87,7 +96,7 @@ fixef.sdmTMB <- function(object, ...) {
 #' @method ranef sdmTMB
 #' @export
 ranef.sdmTMB <- function(object, ...) {
-  .t <- tidy(object, "ran_vals", conf.int = FALSE)
+  .t <- tidy(object, "ran_vals", conf.int = FALSE, silent = TRUE)
   terms <- unlist(lapply(strsplit(.t$term,"_"), getElement, 1))
   est <- .t$estimate
   cond <- list()
@@ -125,7 +134,7 @@ vcov.sdmTMB <- function(object, ...) {
   rn <- rownames(vc)
   bj <- grepl("^b_j", rn)
   vc <- vc[bj, bj]
-  b <- tidy(object)
+  b <- tidy(object, silent = TRUE)
   stopifnot(nrow(b) == nrow(vc))
   rownames(vc) <- b$term
   colnames(vc) <- b$term
@@ -169,7 +178,7 @@ Effect.sdmTMB <- function(focal.predictors, mod, ...) {
   }
 
   vc <- vcov(mod)
-  b <- tidy(mod)
+  b <- tidy(mod, silent = TRUE)
 
   dummyfuns <- list(
     variance = function(mu) mu,
