@@ -3,9 +3,10 @@ test_that("Forecasting works with a time-varying parameter", {
   skip_on_ci()
   skip_if_not_installed("INLA")
   spde <- make_mesh(pcod, c("X", "Y"), n_knots = 50, type = "kmeans")
-  grid2019 <- qcs_grid[qcs_grid$year == max(qcs_grid$year), ]
+  nd <- replicate_df(qcs_grid, "year", unique(pcod$year))
+  grid2019 <- nd[nd$year == max(nd$year), ]
   grid2019$year <- 2019L
-  qcsgrid_forecast <- rbind(qcs_grid, grid2019)
+  qcsgrid_forecast <- rbind(nd, grid2019)
   grid2019$year <- 2018L
   qcsgrid_forecast <- rbind(qcsgrid_forecast, grid2019)
   grid2019$year <- 2016L
